@@ -20,10 +20,10 @@
 #' m3 <- lmer(Reaction ~ Days + (1 | Subject), data = sleepstudy)
 #' m4 <- glm(formula = vs ~ wt, family = binomial(), data = mtcars)
 #'
-#' all_models_equal(m1, m2)
-#' all_models_equal(m1, m2, m3)
-#' all_models_equal(m1, m4, m2, m3, verbose = TRUE)
-#' all_models_equal(m1, m4, mtcars, m2, m3, verbose = TRUE)
+#' all_models_same_class(m1, m2)
+#' all_models_same_class(m1, m2, m3)
+#' all_models_same_class(m1, m4, m2, m3, verbose = TRUE)
+#' all_models_same_class(m1, m4, mtcars, m2, m3, verbose = TRUE)
 #'
 #' @export
 all_models_equal <- function(..., verbose = FALSE) {
@@ -32,7 +32,13 @@ all_models_equal <- function(..., verbose = FALSE) {
 
   all_supported <- sapply(objects, is_model)
   all_classes <- sapply(objects, class)
-  all_equal <- Reduce(identical, all_classes)
+
+  if (is.matrix(all_classes))
+    all_classes <- as.vector(all_classes[1, ])
+  else if (is.list(all_classes))
+    all_classes <- sapply(all_classes, function(i) i[1])
+
+  all_equal <- all(sapply(all_classes[-1], function(i) identical(i, all_classes[1])))
 
   if (!all(all_supported) && verbose) {
     differ <- which(!all_supported)
@@ -66,3 +72,8 @@ all_models_equal <- function(..., verbose = FALSE) {
 
   all(all_supported) && all(all_equal)
 }
+
+
+#' @rdname all_models_equal
+#' @export
+all_models_same_class <- all_models_equal
\ No newline at end of file
