@@ -8,6 +8,11 @@
 
 
 
+# remove empty string from character
+.compact_character <- function(x) x[!sapply(x, function(i) nchar(i) == 0 || is.null(i) || any(i == "NULL"))]
+
+
+
 # remove values from vector
 .remove_values <- function(x, values) {
   remove <- x %in% values
