@@ -28,7 +28,7 @@ link_inverse <- function(x, ...) {
 
 #' @export
 link_inverse.default <- function(x, ...) {
-  if (inherits(x, "list") && obj_has_name(x, "gam")) {
+  if (inherits(x, "list") && .obj_has_name(x, "gam")) {
     x <- x$gam
     class(x) <- c(class(x), c("glm", "lm"))
   }
@@ -126,6 +126,12 @@ link_inverse.coxph <- function(x, ...) {
 }
 
 
+#' @export
+link_inverse.survfit <- function(x, ...) {
+  stats::make.link("logit")$linkinv
+}
+
+
 #' @export
 link_inverse.coxme <- function(x, ...) {
   stats::make.link("logit")$linkinv
@@ -334,6 +340,24 @@ link_inverse.mlogit <- function(x, ...) {
 }
 
 
+#' @export
+link_inverse.BBreg <- function(x, ...) {
+  stats::make.link("logit")$linkinv
+}
+
+
+#' @export
+link_inverse.BBmm <- function(x, ...) {
+  stats::make.link("logit")$linkinv
+}
+
+
+#' @export
+link_inverse.glimML <- function(x, ...) {
+  stats::make.link(x@link)$linkinv
+}
+
+
 #' @export
 link_inverse.clm <- function(x, ...) {
   stats::make.link(get_ordinal_link(x))$linkinv
