@@ -56,9 +56,9 @@ if (require("testthat") && require("insight") && require("glmmTMB")) {
     )
   })
 
-  test_that("find_terms", {
-    expect_equal(find_terms(m1), list(response = "count", conditional = c("mined", "cover", "sample")))
-    expect_equal(find_terms(m1, flatten = TRUE), c("count", "mined", "cover", "sample"))
+  test_that("find_variables", {
+    expect_equal(find_variables(m1), list(response = "count", conditional = c("mined", "cover", "sample")))
+    expect_equal(find_variables(m1, flatten = TRUE), c("count", "mined", "cover", "sample"))
   })
 
   test_that("n_obs", {
@@ -84,9 +84,9 @@ if (require("testthat") && require("insight") && require("glmmTMB")) {
     expect_false(is_multivariate(m1))
   })
 
-  test_that("find_variables", {
+  test_that("find_terms", {
     expect_equal(
-      find_variables(m1),
+      find_terms(m1),
       list(
         response = "count",
         conditional = c("mined", "log(cover)", "sample")
