@@ -4,7 +4,7 @@ if (require("testthat") && require("insight") && require("panelr")) {
   data("WageData")
   wages <- panel_data(WageData, id = id, wave = t)
   m1 <- wbm(lwage ~ lag(union) + wks | blk + fem | blk * lag(union), data = wages)
-  m2 <- wbm(lwage ~ lag(union) + wks | blk + fem | blk * (t | union), data = wages)
+  m2 <- wbm(lwage ~ lag(union) + wks | blk + fem | blk * (t | id), data = wages)
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_linear)
@@ -17,17 +17,17 @@ if (require("testthat") && require("insight") && require("panelr")) {
     expect_identical(find_predictors(m1, effects = "random"), list(random = "lag(union)"))
 
     expect_identical(find_predictors(m2), list(conditional = c("union", "wks"), instruments = c("blk", "fem")))
-    expect_identical(find_predictors(m2, effects = "random"), list(random = "union"))
+    expect_identical(find_predictors(m2, effects = "random"), list(random = "id"))
   })
 
   test_that("find_random", {
     expect_identical(find_random(m1), list(random = "lag(union)"))
-    expect_identical(find_random(m2), list(random = "union"))
+    expect_identical(find_random(m2), list(random = "id"))
   })
 
   test_that("get_random", {
     expect_equal(get_random(m1)[[1]], model.frame(m1)$`lag(union)`)
-    expect_equal(get_random(m2)[[1]], model.frame(m2)$union)
+    expect_equal(get_random(m2)[[1]], model.frame(m2)$id)
   })
 
   test_that("find_response", {
@@ -56,7 +56,7 @@ if (require("testthat") && require("insight") && require("panelr")) {
     )
     expect_equal(
       colnames(get_data(m2)),
-      c("lwage", "id", "t", "lag(union)", "wks", "blk", "fem", "union",  "imean(lag(union))", "imean(wks)")
+      c("lwage", "id", "t", "lag(union)", "wks", "blk", "fem", "imean(lag(union))", "imean(wks)")
     )
   })
 
@@ -76,7 +76,7 @@ if (require("testthat") && require("insight") && require("panelr")) {
       list(
         conditional = as.formula("lwage ~ lag(union) + wks"),
         instruments = as.formula("~blk + fem"),
-        random = as.formula("~blk * t | union")
+        random = as.formula("~blk * t | id")
       )
     )
   })
@@ -85,8 +85,8 @@ if (require("testthat") && require("insight") && require("panelr")) {
     expect_equal(find_variables(m1), list(response = "lwage", conditional = c("union", "wks"), instruments = c("blk", "fem"), random = "lag(union)"))
     expect_equal(find_variables(m1, flatten = TRUE), c("lwage", "union", "wks", "blk", "fem", "lag(union)"))
 
-    expect_equal(find_variables(m2), list(response = "lwage", conditional = c("union", "wks"), instruments = c("blk", "fem"), random = "union"))
-    expect_equal(find_variables(m2, flatten = TRUE), c("lwage", "union", "wks", "blk", "fem"))
+    expect_equal(find_variables(m2), list(response = "lwage", conditional = c("union", "wks"), instruments = c("blk", "fem"), random = "id"))
+    expect_equal(find_variables(m2, flatten = TRUE), c("lwage", "union", "wks", "blk", "fem", "id"))
   })
 
   test_that("n_obs", {
@@ -112,8 +112,7 @@ if (require("testthat") && require("insight") && require("panelr")) {
       find_parameters(m2),
       list(
         conditional = c("(Intercept)", "imean(lag(union))", "imean(wks)", "lag(union)", "wks", "blk", "fem"),
-        random = list(id = "(Intercept)",
-                      union = c("(Intercept)", "t")))
+        random = list(id = c("(Intercept)", "t")))
     )
 
   })
@@ -127,7 +126,7 @@ if (require("testthat") && require("insight") && require("panelr")) {
     expect_equal(
       find_terms(m2),
       list(response = "lwage", conditional = c("lag(union)", "wks"),
-           instruments = c("blk", "fem"), random = c("blk", "t", "union"))
+           instruments = c("blk", "fem"), random = c("blk", "t", "id"))
     )
   })
 
